@@ -12,12 +12,13 @@ def normaliza_conteudo_de_resposta(resposta):
 
 def grava_evidencia_envio(meio_pagamento, para, dados, resposta, conta_id, pedido_numero):
     normaliza_conteudo_de_resposta(resposta)
+
     evidencia = {
-        "tipo_evidencia": "pagador-envio",
+        "index": "pagador",
+        "tipo_evidencia": meio_pagamento + '-' + "envio",
         "evidencia": {
             "conta_id": conta_id,
             "pedido_numero": pedido_numero,
-            "meio_pagamento": meio_pagamento,
             "envio": {
                 "dados": dados,
                 "url":  para
@@ -25,6 +26,7 @@ def grava_evidencia_envio(meio_pagamento, para, dados, resposta, conta_id, pedid
             "resposta": resposta
         }
     }
+
     try:
         evidencia = json.dumps(evidencia)
         headers = {"Content-Type": "application/json"}
